@@ -3,7 +3,7 @@ import filecmp
 import numpy as np
 import pytest
 
-from dr_files.utilities import dr_to_tdms, dr_to_values, dr_to_wav
+from dr_files.utilities import dr_to_csv, dr_to_tdms, dr_to_values, dr_to_wav
 
 
 def test_values():
@@ -19,3 +19,8 @@ def test_wav():
 def test_tdms():
     dr_to_tdms("./fixtures/demo.dr", "/tmp/dr.tdms")
     assert filecmp.cmp("./fixtures/demo.tdms", "/tmp/dr.tdms", shallow=True)
+
+
+def test_csv():
+    dr_to_csv("./fixtures/demo.dr", "/tmp/dr.csv")
+    assert filecmp.cmp("./fixtures/demo.csv", "/tmp/dr.csv", shallow=True)
