@@ -93,24 +93,27 @@ def dr_to_csv(file_path: os.PathLike, out_file_path: os.PathLike):
     Reads a Mechbase file found in file_path, converts it to CSV and writes it at out_file_path.
     """
     header, signals = dr_to_values(file_path)
-    h_row = ["Time"]
+    h_row = ["time"]
     for i in range(len(header.channels)):
-        h_row.append(f"Channel {i + 1}")
+        h_row.append(f"channel {i + 1}")
     with open(out_file_path, "w+") as fout:
         w = csv.writer(fout)
         w.writerow(h_row)
         rows = []
 
         time = 0
-        for index, _ in enumerate(signals[0]):
+        fs = 1 / header.sample_rate
+        for signal_values in zip(*signals):
             row = [time]
-            time += 1 / header.sample_rate
-            for s in signals:
-                row.append(s[index])
-            rows.append(row)
-            if len(rows) > LINE_BUFFER:
-                w.writerows(rows)
-                rows = []
+            row.extend(signal_values)
+            time += fs
+
+            rows.append(list(map(lambda value: format(value, ".10f"), row)))
+            if len(rows) < LINE_BUFFER:
+                continue
+
+            w.writerows(rows)
+            rows = []
 
         w.writerows(rows)
 
